﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

//1. Log4Net 네임스페이스를 using한여 Log4Net을 사용 할 수 있도록 한다..
using log4net;
using log4net.Config;

namespace Log4NetSample
{
    /// <summary>
    /// 본 소스 코드는 C# 코드에서 Log4Net을 이용하여 로깅하는 예제를 보여주고 있습니다.
    /// author : 신윤섭
    /// </summary>

    public partial class Window1 : System.Windows.Window
    {
        //3. Log4Net 인터페이스를 취득하여 해당 클래스에서 Log4Net 클래스를 사용 할 수 있도록 한다.
        //private static readonly ILog logger = LogManager.GetLogger(typeof(Window1));  // XmlConfigurator.Configure() 실행 이후 시점부터 일반 클래스에서 로거객체 취득방법.

        /// <summary>
        /// default constructor
        /// </summary>
        public Window1()
        {
            InitializeComponent();

            // 2. 어플리케이션 초기 구동시 Log4Net이 참조할 환경 설정파일을 Log4Net이 알 수 있도록 한다. 
            //    한번만 실행하여 설정 파일이 메모리에 로드되도록하면 됨.
            //XmlConfigurator.Configure();  // <- Application base 디렉토리의  Window1.exe.config 파일을 읽어들일 때.
            XmlConfigurator.Configure(new System.IO.FileInfo("log4net.xml")); // <- Application base 디렉토리의 log4net.xml을 읽어들일 때. 


            // 3.Log4Net 인터페이스를 취득하여 해당 클래스에서 Log4Net 클래스를 사용 할 수 있도록 한다.
            ILog logger = LogManager.GetLogger(typeof(Window1)); // 혹은ILog logger = LogManager.GetLogger( Type.GetType("Log4NetSample.Window1") );

            
            // 4. 로거 인터페이스를 이용하여 로깅 레벨 별로 로그 기록
            if (logger.IsDebugEnabled)
            {
                logger.Debug( this.ToString()+ "인스턴스 생성 됨" );
            }
        }


        /// <summary>
        /// EventHandler
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void button_Click(object sender, RoutedEventArgs e)
        {
            ILog logger = LogManager.GetLogger(typeof(Window1));

            // 디버그 메세지.
            if (logger.IsDebugEnabled) logger.Debug("OnButtonMouseClick 이벤트 발생!!");

            try
            {
                // 일부러 예외상황을 발생 합니다.
                int i = Int32.Parse("exception");

            }
            catch (Exception ex)
            {
                // 에러 메세지.
                if (logger.IsErrorEnabled) logger.Error("에러 발생!!!", ex);
            }
        }


        protected override void OnClosing(System.ComponentModel.CancelEventArgs e)
        {
 	         base.OnClosing(e);
            ILog logger = LogManager.GetLogger(typeof(Window1));

            try
            {
                // 인포메이션 메세지.
                if (logger.IsInfoEnabled) logger.Info("Window1 어플리케이션 종료");

                // 5. Log4Net을 종료하고 리소스를 해제 한다.
                LogManager.Shutdown();

            }
            catch (Exception ex)
            {
                
            }
        }

    }   
}